# wellcadformats

Read in export file formats produced by [Advanced Logic Technology (ALT)](http://www.alt.lu/default.htm)'s [WellCAD](http://www.alt.lu/software.htm) software, and provides a few utility functions for the imaging/waveform data formats.

ASCII export formats supported so far:

- .waw - well logs with a single floating point number per depth
- .waf - full-waveform sonic logs - vector array of floating point numbers per depth
- .wai - image log - vector array of integers per depth

The authors of this package have no affiliation with ALT.
